<?php

namespace Drupal\absolute_urls\Normalizer;

use Drupal\Component\Utility\Html;
use Drupal\views\Render\ViewsRenderPipelineMarkup;
use Drupal\serialization\Normalizer\NormalizerBase;
use Symfony\Component\HttpFoundation\Request;

/**
 * Normalizer for ViewsRenderPipelineMarkup fields.
 */
class AbsoluteDataNormalizer extends NormalizerBase {

  /**
   * The supported interface or class.
   *
   * @var string[]
   */
  protected $supportedInterfaceOrClass = [ViewsRenderPipelineMarkup::class];

  /**
   * {@inheritdoc}
   */
  public function supportsNormalization($data, ?string $format = NULL, array $context = []): bool {
    // Ensure we only process ViewsRenderPipelineMarkup fields and JSON output.
    return $data instanceof ViewsRenderPipelineMarkup && $format === 'json';
  }

  /**
   * {@inheritdoc}
   */
  public function normalize($object, $format = NULL, array $context = []) {
    $base_url = Request::createFromGlobals()->getSchemeAndHttpHost();

    // Convert the ViewsRenderPipelineMarkup object to a string.
    $value = (string) $object;

    // Convert relative URLs to absolute.
    return Html::transformRootRelativeUrlsToAbsolute($value, $base_url);
  }

}
